searchData={"items":[{"type":"module","title":"Membrane.FFmpeg.VideoFilter.TextOverlay","doc":"Element adding text overlay to raw video frames - using 'drawtext' video filter from FFmpeg Library.\n(https://ffmpeg.org/ffmpeg-filters.html#drawtext-1).\nElement allows for specifying most commonly used 'drawtext' settings (such as fontsize, fontcolor) through element options.\n\nThe element expects each frame to be received in a separate buffer.\nAdditionally, the element has to receive proper stream format with picture format and dimensions.","ref":"Membrane.FFmpeg.VideoFilter.TextOverlay.html"},{"type":"module","title":"Element options - Membrane.FFmpeg.VideoFilter.TextOverlay","doc":"Passed via struct `t:Membrane.FFmpeg.VideoFilter.TextOverlay.t/0`\n\n- `text`  \n\n  ```\n  any\n  ```\n  \n  Default value: `nil`  \n  Text to be displayed on video. Either text or text_intervals must be provided\n\n\n- `text_intervals`  \n\n  ```\n  [{{Time.t(), Time.t() | :infinity}, String.t()}]\n  ```\n  \n  Default value: `[]`  \n  List of time intervals when each given text should appear. Intervals should not overlap.\n                  Either text or text_intervals must be provided\n\n\n\n- `font_size`  \n\n  ```\n  any\n  ```\n  \n  Default value: `12`  \n  Size of the displayed font\n\n\n\n- `font_color`  \n\n  ```\n  any\n  ```\n  \n  Default value: `\"black\"`  \n  Choose font color according to the ffmpeg color syntax (https://ffmpeg.org/ffmpeg-utils.html#color-syntax)\n\n\n\n- `font_file`  \n\n  ```\n  any\n  ```\n  \n  Default value: `nil`  \n  Path to the file with the desired font. If not set, default font fallback from fontconfig is used\n\n\n\n- `box?`  \n\n  ```\n  any\n  ```\n  \n  Default value: `false`  \n  Set to true if a box is to be displayed behind the text\n\n\n\n- `box_color`  \n\n  ```\n  any\n  ```\n  \n  Default value: `\"white\"`  \n  If the box? is set to true, display a box in the given color\n\n\n\n- `border_width`  \n\n  ```\n  any\n  ```\n  \n  Default value: `0`  \n  Set the width of the border around the text\n\n\n\n- `border_color`  \n\n  ```\n  any\n  ```\n  \n  Default value: `\"black\"`  \n  Set the color of the border, if exists\n\n\n\n- `horizontal_align`  \n\n  ```\n  :left | :right | :center\n  ```\n  \n  Default value: `:left`  \n  Horizontal position of the displayed text\n\n\n\n- `vertical_align`  \n\n  ```\n  :top | :bottom | :center\n  ```\n  \n  Default value: `:bottom`  \n  Vertical position of the displayed text","ref":"Membrane.FFmpeg.VideoFilter.TextOverlay.html#module-element-options"},{"type":"module","title":"Pads - Membrane.FFmpeg.VideoFilter.TextOverlay","doc":"### `:input`\n\nAccepted formats:\n```\n%RawVideo{aligned: true}\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\n\n\n### `:output`\n\nAccepted formats:\n```\n%RawVideo{aligned: true}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`","ref":"Membrane.FFmpeg.VideoFilter.TextOverlay.html#module-pads"},{"type":"function","title":"Membrane.FFmpeg.VideoFilter.TextOverlay.options/0","doc":"Returns description of options available for this module","ref":"Membrane.FFmpeg.VideoFilter.TextOverlay.html#options/0"},{"type":"type","title":"Membrane.FFmpeg.VideoFilter.TextOverlay.t/0","doc":"Struct containing options for `Membrane.FFmpeg.VideoFilter.TextOverlay`","ref":"Membrane.FFmpeg.VideoFilter.TextOverlay.html#t:t/0"},{"type":"extras","title":"Membrane FFmpeg Video Filter Plugin","doc":"# Membrane FFmpeg Video Filter Plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_ffmpeg_video_filter_plugin.svg)](https://hex.pm/packages/membrane_ffmpeg_video_filter_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_ffmpeg_video_filter_plugin)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_ffmpeg_video_filter_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_ffmpeg_video_filter_plugin)\n\nThis package contains elements providing video filters based on [ffmpeg video filter feature](https://ffmpeg.org/ffmpeg-filters.html#Video-Filters).\n\nCurrently only the TextOverlay element is implemented, based on [ffmpeg drawtext filter](https://ffmpeg.org/ffmpeg-filters.html#drawtext-1).\nThis element enables adding text on top of given raw video frames.\n\nPRs with the implementation of other video filters are welcome!","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane FFmpeg Video Filter Plugin","doc":"The package can be installed by adding `membrane_ffmpeg_video_filter_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n\t{:membrane_ffmpeg_video_filter_plugin, \"~> 0.13.1\"}\n  ]\nend\n```\n\nThe precompiled builds of the [ffmpeg](https://www.ffmpeg.org) will be pulled and linked automatically. However, should there be any problems, consider installing it manually.\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"Manual instalation of dependencies - Membrane FFmpeg Video Filter Plugin","doc":"##","ref":"readme.html#manual-instalation-of-dependencies"},{"type":"extras","title":"macOS - Membrane FFmpeg Video Filter Plugin","doc":"```shell\nbrew install ffmpeg\n```\n\n##","ref":"readme.html#macos"},{"type":"extras","title":"Ubuntu - Membrane FFmpeg Video Filter Plugin","doc":"```shell\nsudo apt-get install ffmpeg\n```\n\n##","ref":"readme.html#ubuntu"},{"type":"extras","title":"Arch / Manjaro - Membrane FFmpeg Video Filter Plugin","doc":"```shell\npacman -S ffmpeg\n```","ref":"readme.html#arch-manjaro"},{"type":"extras","title":"Usage - Membrane FFmpeg Video Filter Plugin","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"TextOverlay - Membrane FFmpeg Video Filter Plugin","doc":"Below example pipeline adds \"John Doe\" text over h264 video in a specified style.\n\n```elixir\ndefmodule VideoFilter.Pipeline do\n  use Membrane.Pipeline\n\n  alias Membrane.File.{Sink, Source}\n  alias Membrane.H264.FFmpeg.{Parser, Decoder, Encoder}\n  alias Membrane.FFmpeg.VideoFilter.TextOverlay\n\n  @impl true\n  def handle_init(_ctx, _opts) do\n    structure =\n      child(:file_src, %Source{location: \"input.h264\"})\n      |> child(:parser, %Parser{framerate: {10, 1}})\n      |> child(:decoder, Decoder)\n      |> child(:text_filter, %TextOverlay{\n          text: \"John Doe\",\n          x: :center,\n          fontsize: 25,\n          fontcolor: \"white\",\n          border?: true\n        }\n      )\n      |> child(:encoder,  Encoder)\n      |> child(:file_sink,  %Sink{location: \"output.h264\"})\n\n    {[spec: structure], %{}}\n  end\nend\n```\n\nFrame from original video:\n\n![input](readme/input.png)\n\nOutput frame with filter applied:\n\n![output](readme/output.png)","ref":"readme.html#textoverlay"},{"type":"extras","title":"Copyright and License - Membrane FFmpeg Video Filter Plugin","doc":"Copyright 2021, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_ffmpeg_video_filter_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_ffmpeg_video_filter_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2020 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}